{
    "$graph": [
        {
            "label": "Merge rRNA Alignments",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_merge",
            "arguments": [
                "-filter",
                "align_length >= 60",
                "-ifmt",
                "seq-align-set",
                "-max-discontinuity",
                "20",
                "-collated",
                "-compart",
                "-fill-gaps"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_merge.cwl/alignments"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#align_merge.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#align_merge.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#align_merge.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_merge.cwl/output"
                }
            ],
            "id": "#align_merge.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_merge.cwl/aligns"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#align_merge.cwl/asncache"
                }
            ]
        },
        {
            "label": "BLAST against rRNA db, execution",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "blastn_wnode",
            "arguments": [
                "-evalue",
                "0.01",
                "-max_target_seqs",
                "250",
                "-soft_masking",
                "true",
                "-task",
                "blastn",
                "-word_size",
                "12",
                "-swap-rows"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#blastn_wnode.cwl/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#blastn_wnode.cwl/blastdb_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#blastn_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#blastn_wnode.cwl/output_dir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#blastn_wnode.cwl/asncache"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#blastn_wnode.cwl/outdir"
                }
            ],
            "id": "#blastn_wnode.cwl"
        },
        {
            "label": "BLAST against rRNA db, gather",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "gpx_make_outputs",
            "arguments": [
                "-unzip",
                "*",
                "-num-partitions",
                "1"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_make_outputs.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blast.#.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_make_outputs.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "blast.*.asn"
                    },
                    "id": "#gpx_make_outputs.cwl/blast_align"
                }
            ],
            "id": "#gpx_make_outputs.cwl"
        },
        {
            "label": "BLAST against rRNA db, scatter",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-affinity",
                "subject",
                "-max-batch-length",
                "50000"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-db",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/asncache"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_blastn.cwl"
        },
        {
            "label": "Generate rRNA Annotation",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "ribosomal_align2annot",
            "arguments": [
                "-filter-accept",
                "pct_identity_gap >= 70",
                "-gap-tolerance",
                "1000",
                "-submission-mode-genbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#ribosomal_align2annot.cwl/alignments"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "annotations.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotation"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#ribosomal_align2annot.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#ribosomal_align2annot.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#ribosomal_align2annot.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-product-name"
                    },
                    "id": "#ribosomal_align2annot.cwl/product_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.annotation)"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotations"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#ribosomal_align2annot.cwl/asncache"
                }
            ],
            "id": "#ribosomal_align2annot.cwl"
        },
        {
            "label": "BLAST against rRNA db",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": "string",
                    "id": "#main/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#main/blastdb_dir"
                },
                {
                    "type": "string",
                    "id": "#main/outname"
                },
                {
                    "type": "string",
                    "id": "#main/product_name"
                },
                {
                    "type": "File",
                    "id": "#main/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/ribosomal_align2annot/annotations",
                    "id": "#main/annotations"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/ribosomal_align2annot/asncache",
                    "id": "#main/asncache"
                }
            ],
            "steps": [
                {
                    "run": "#align_merge.cwl",
                    "in": [
                        {
                            "source": "#main/gpx_make_outputs/blast_align",
                            "id": "#main/align_merge/alignments"
                        },
                        {
                            "source": "#main/blastn_wnode/asncache",
                            "id": "#main/align_merge/asn_cache"
                        },
                        {
                            "source": "#main/blastdb",
                            "id": "#main/align_merge/blastdb"
                        },
                        {
                            "source": "#main/blastdb_dir",
                            "id": "#main/align_merge/blastdb_dir"
                        }
                    ],
                    "out": [
                        "#main/align_merge/asncache",
                        "#main/align_merge/aligns"
                    ],
                    "id": "#main/align_merge"
                },
                {
                    "run": "#blastn_wnode.cwl",
                    "in": [
                        {
                            "source": "#main/gpx_qsubmit/asncache",
                            "id": "#main/blastn_wnode/asn_cache"
                        },
                        {
                            "source": "#main/blastdb_dir",
                            "id": "#main/blastn_wnode/blastdb_dir"
                        },
                        {
                            "source": "#main/gpx_qsubmit/jobs",
                            "id": "#main/blastn_wnode/input_jobs"
                        }
                    ],
                    "out": [
                        "#main/blastn_wnode/asncache",
                        "#main/blastn_wnode/outdir"
                    ],
                    "id": "#main/blastn_wnode"
                },
                {
                    "run": "#gpx_make_outputs.cwl",
                    "in": [
                        {
                            "source": "#main/blastn_wnode/outdir",
                            "id": "#main/gpx_make_outputs/input_path"
                        }
                    ],
                    "out": [
                        "#main/gpx_make_outputs/blast_align"
                    ],
                    "id": "#main/gpx_make_outputs"
                },
                {
                    "run": "#gpx_qsubmit_blastn.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#main/blastdb",
                            "id": "#main/gpx_qsubmit/blastdb"
                        },
                        {
                            "source": "#main/blastdb_dir",
                            "id": "#main/gpx_qsubmit/blastdb_dir"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/gpx_qsubmit/seqids"
                        }
                    ],
                    "out": [
                        "#main/gpx_qsubmit/asncache",
                        "#main/gpx_qsubmit/jobs"
                    ],
                    "id": "#main/gpx_qsubmit"
                },
                {
                    "run": "#ribosomal_align2annot.cwl",
                    "in": [
                        {
                            "source": "#main/align_merge/aligns",
                            "id": "#main/ribosomal_align2annot/alignments"
                        },
                        {
                            "source": "#main/outname",
                            "id": "#main/ribosomal_align2annot/annotation"
                        },
                        {
                            "source": "#main/align_merge/asncache",
                            "id": "#main/ribosomal_align2annot/asn_cache"
                        },
                        {
                            "source": "#main/blastdb",
                            "id": "#main/ribosomal_align2annot/blastdb"
                        },
                        {
                            "source": "#main/blastdb_dir",
                            "id": "#main/ribosomal_align2annot/blastdb_dir"
                        },
                        {
                            "source": "#main/product_name",
                            "id": "#main/ribosomal_align2annot/product_name"
                        }
                    ],
                    "out": [
                        "#main/ribosomal_align2annot/asncache",
                        "#main/ribosomal_align2annot/annotations"
                    ],
                    "id": "#main/ribosomal_align2annot"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
